@@ -537,82 +537,82 @@ class GenericCRUD(metaclass=MetaLogger, object=LOGGER_CRUD_CODE_OBJECT):
     def __add_create_updated_user_profile_ids(self, data_json: dict, add_created_user_id: bool = False,
                                               schema_name: str = None, table_name: str = None) -> dict:
         """Adds created_user_id and updated_user_id to data_json."""
-        if get_environment_name() not in (EnvironmentName.DVLP1.value, EnvironmentName.PROD1.value):
-            schema_name = schema_name or self.schema_name
-            table_name = table_name or self.default_table_name
-            columns_dict = self.get_columns_dict(schema_name=schema_name, table_name=table_name)
-            if add_created_user_id:
-                if "created_user_id" in columns_dict:
-                    data_json["created_user_id"] = self.user_context.get_effective_user_id()
-                else:
-                    self.__log_warning("created_user_id", schema_name, table_name)
-                if "created_real_user_id" in columns_dict:
-                    data_json["created_real_user_id"] = self.user_context.get_real_user_id()
-                else:
-                    self.__log_warning("created_real_user_id", schema_name, table_name)
-                if "created_effective_user_id" in columns_dict:
-                    data_json["created_effective_user_id"] = self.user_context.get_effective_user_id()
-                else:
-                    self.__log_warning("created_effective_user_id", schema_name, table_name)
-                if "created_effective_profile_id" in columns_dict:
-                    data_json["created_effective_profile_id"] = self.user_context.get_effective_profile_id()
-                else:
-                    self.__log_warning("created_effective_profile_id", schema_name, table_name)
-                if "number" in columns_dict:
-                    # TODO: the commented line caused errors, we need to check it
-                    # view_name = self.default_view_table_name or self._get_view_name(table_name)
-                    view_name = table_name
-                    number = NumberGenerator.get_random_number(schema_name=schema_name, view_name=view_name)
-                    data_json["number"] = number
-                else:
-                    self.__log_warning("number", schema_name, table_name)
-
-                if "identifier" in columns_dict:
-                    self.__add_identifier(data_json=data_json, table_name=table_name)
-
-                else:
-                    self.__log_warning("identifier", schema_name, table_name)
-            if "updated_user_id" in columns_dict:
-                data_json["updated_user_id"] = self.user_context.get_effective_user_id()
-            else:
-                self.__log_warning("updated_user_id", schema_name, table_name)
-            if "updated_real_user_id" in columns_dict:
-                data_json["updated_real_user_id"] = self.user_context.get_real_user_id()
-            else:
-                self.__log_warning("updated_real_user_id", schema_name, table_name)
-            if "updated_effective_user_id" in columns_dict:
-                data_json["updated_effective_user_id"] = self.user_context.get_effective_user_id()
-            else:
-                self.__log_warning("updated_effective_user_id", schema_name, table_name)
-            if "updated_effective_profile_id" in columns_dict:
-                data_json["updated_effective_profile_id"] = self.user_context.get_effective_profile_id()
-            else:
-                self.__log_warning("updated_effective_profile_id", schema_name, table_name)
-            # TODO: later we may want to add a check for the table_definition to see if there is a column for is_test_data
-            if "is_test_data" in columns_dict:
-                data_json["is_test_data"] = self.is_test_data
-            else:
-                self.__log_warning("is_test_data", schema_name, table_name)
-        else:
-            schema_name = schema_name or self.schema_name
-            table_name = table_name or self.default_table_name
-            if add_created_user_id:
+        # if get_environment_name() not in (EnvironmentName.DVLP1.value, EnvironmentName.PROD1.value):
+        schema_name = schema_name or self.schema_name
+        table_name = table_name or self.default_table_name
+        columns_dict = self.get_columns_dict(schema_name=schema_name, table_name=table_name)
+        if add_created_user_id:
+            if "created_user_id" in columns_dict:
                 data_json["created_user_id"] = self.user_context.get_effective_user_id()
+            else:
+                self.__log_warning("created_user_id", schema_name, table_name)
+            if "created_real_user_id" in columns_dict:
                 data_json["created_real_user_id"] = self.user_context.get_real_user_id()
+            else:
+                self.__log_warning("created_real_user_id", schema_name, table_name)
+            if "created_effective_user_id" in columns_dict:
                 data_json["created_effective_user_id"] = self.user_context.get_effective_user_id()
+            else:
+                self.__log_warning("created_effective_user_id", schema_name, table_name)
+            if "created_effective_profile_id" in columns_dict:
                 data_json["created_effective_profile_id"] = self.user_context.get_effective_profile_id()
+            else:
+                self.__log_warning("created_effective_profile_id", schema_name, table_name)
+            if "number" in columns_dict:
                 # TODO: the commented line caused errors, we need to check it
-                # view_name = self._get_view_name(table_name)
+                # view_name = self.default_view_table_name or self._get_view_name(table_name)
                 view_name = table_name
                 number = NumberGenerator.get_random_number(schema_name=schema_name, view_name=view_name)
                 data_json["number"] = number
+            else:
+                self.__log_warning("number", schema_name, table_name)
 
-                # self.__add_identifier(data_json=data_json)
+            if "identifier" in columns_dict:
+                self.__add_identifier(data_json=data_json, table_name=table_name)
+
+            else:
+                self.__log_warning("identifier", schema_name, table_name)
+        if "updated_user_id" in columns_dict:
             data_json["updated_user_id"] = self.user_context.get_effective_user_id()
+        else:
+            self.__log_warning("updated_user_id", schema_name, table_name)
+        if "updated_real_user_id" in columns_dict:
             data_json["updated_real_user_id"] = self.user_context.get_real_user_id()
+        else:
+            self.__log_warning("updated_real_user_id", schema_name, table_name)
+        if "updated_effective_user_id" in columns_dict:
             data_json["updated_effective_user_id"] = self.user_context.get_effective_user_id()
+        else:
+            self.__log_warning("updated_effective_user_id", schema_name, table_name)
+        if "updated_effective_profile_id" in columns_dict:
             data_json["updated_effective_profile_id"] = self.user_context.get_effective_profile_id()
+        else:
+            self.__log_warning("updated_effective_profile_id", schema_name, table_name)
+        # TODO: later we may want to add a check for the table_definition to see if there is a column for is_test_data
+        if "is_test_data" in columns_dict:
             data_json["is_test_data"] = self.is_test_data
+        else:
+            self.__log_warning("is_test_data", schema_name, table_name)
+        # else:
+        #     schema_name = schema_name or self.schema_name
+        #     table_name = table_name or self.default_table_name
+        #     if add_created_user_id:
+        #         data_json["created_user_id"] = self.user_context.get_effective_user_id()
+        #         data_json["created_real_user_id"] = self.user_context.get_real_user_id()
+        #         data_json["created_effective_user_id"] = self.user_context.get_effective_user_id()
+        #         data_json["created_effective_profile_id"] = self.user_context.get_effective_profile_id()
+        #         # TODO: the commented line caused errors, we need to check it
+        #         # view_name = self._get_view_name(table_name)
+        #         view_name = table_name
+        #         number = NumberGenerator.get_random_number(schema_name=schema_name, view_name=view_name)
+        #         data_json["number"] = number
+        #
+        #         # self.__add_identifier(data_json=data_json)
+        #     data_json["updated_user_id"] = self.user_context.get_effective_user_id()
+        #     data_json["updated_real_user_id"] = self.user_context.get_real_user_id()
+        #     data_json["updated_effective_user_id"] = self.user_context.get_effective_user_id()
+        #     data_json["updated_effective_profile_id"] = self.user_context.get_effective_profile_id()
+        #     data_json["is_test_data"] = self.is_test_data
         return data_json
 
     def __log_warning(self, column_name: str, schema_name: str, table_name: str):
