@@ -10,8 +10,7 @@ from .constants import DEFAULT_SQL_SELECT_LIMIT, LOGGER_CRUD_ML_CODE_OBJECT
 from .generic_crud import GenericCRUD
 from .utils import validate_select_table_name
 
-TEST_TABLE_NAME = 'test_mysql_table'
-TEST_ML_TABLE_NAME = 'test_mysql_ml_table'
+IS_MAIN_COLUMN_NAME = "is_main"
 
 
 class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_CODE_OBJECT):
@@ -19,6 +18,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
 
     def __init__(self, default_schema_name: str, default_table_name: str = None,
                  default_id_column_name: str = None,
+                 is_main_column_name: str = IS_MAIN_COLUMN_NAME,
                  is_test_data: bool = False) -> None:
         """Initializes the GenericCRUDML class. If connection is not provided,
         a new connection will be created."""
@@ -36,6 +36,8 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
                              default_id_column_name=default_id_column_name,
                              is_test_data=is_test_data)
         self.user_context = UserContext()
+        # TODO: we may have to change it to a list when we will have multiple is_main columns
+        self.is_main_column_name = is_main_column_name
 
     def sql_in_list_by_entity_list_id(self, schema_name: str, entity_name: str, entity_list_id: int) -> str:
         """Example: select group_id from group.group_list_member_table WHERE group_list_id=1"""
@@ -56,13 +58,14 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
 
     def add_value(self, data_ml_json: dict, table_id: int = None, lang_code: LangCode = None,
                   is_main: int = 0, data_json: dict = None, table_name: str = None,
-                  ml_table_name: str = None) -> Optional[tuple]:
+                  ml_table_name: str = None, schema_name: str = None) -> Optional[tuple]:
 
         lang_code_str = self._get_lang_code_str(lang_code=lang_code, data_ml_json=data_ml_json)
+        old_schema_name = self.schema_name
+        self.schema_name = schema_name or self.schema_name
         table_name = table_name or self.default_table_name
         ml_table_name = ml_table_name or self.default_ml_table_name
 
-        ml_table_id = None
         old_cursor = self.cursor
         try:
             cursor = self.connection.cursor()
@@ -89,7 +92,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
             id_column_name = re.sub(r'(_table)$', '_id', table_name)
             data_ml_json[id_column_name] = table_id
             data_ml_json["lang_code"] = lang_code_str
-            data_ml_json["is_main"] = is_main
+            data_ml_json[self.is_main_column_name] = is_main
 
             # ml_id is the id value of the row in the ml_table_name table
             ml_table_id = self.insert(data_json=data_ml_json, table_name=ml_table_name, ignore_duplicate=True,
@@ -101,6 +104,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
             raise e
         finally:
             self.cursor = old_cursor
+            self.schema_name = old_schema_name
             cursor.close()
         return table_id, ml_table_id
 
@@ -112,6 +116,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
         table_name = table_name or self.default_table_name
         ml_table_name = ml_table_name or self.default_ml_table_name
         id_column_name = GenericCRUD.generate_id_column_name(table_name)
+        ml_id_column_name = GenericCRUD.generate_id_column_name(ml_table_name)
 
         # check if the row exists in the ml_table
         name = data_ml_json.get("title") or data_ml_json.get("name")
@@ -121,7 +126,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
                                                    lang_code=lang_code,
                                                    id_column_name=id_column_name, order_by=order_by)
         ml_table_id = self.get_ml_id_by_name(ml_table_name=ml_table_name, name=name, lang_code=lang_code,
-                                             id_column_name=id_column_name, order_by=order_by)
+                                             id_column_name=ml_id_column_name, order_by=order_by)
         if not table_id:
             return self.add_value(data_ml_json=data_ml_json, table_id=table_id, lang_code=lang_code, is_main=is_main,
                                   data_json=data_json, table_name=table_name, ml_table_name=ml_table_name)
@@ -133,7 +138,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
                            table_name: str = None, ml_table_name: str = None,
                            schema_name: str = None, limit: int = DEFAULT_SQL_SELECT_LIMIT,
                            order_by: str = None) -> tuple:
-
+        old_schema_name = self.schema_name
         self.schema_name = schema_name or self.schema_name
         lang_code_str = self._get_lang_code_str(lang_code=lang_code, data_ml_json=data_ml_json)
         table_name = table_name or self.default_table_name
@@ -158,7 +163,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
 
             data_ml_json[id_column_name] = table_id
             data_ml_json["lang_code"] = lang_code_str
-            data_ml_json["is_main"] = is_main
+            data_ml_json[self.is_main_column_name] = is_main
             id_column_name = GenericCRUD.generate_id_column_name(ml_table_name)
 
             self.update_by_id(data_json=data_ml_json, table_name=ml_table_name, id_column_name=id_column_name,
@@ -170,10 +175,12 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
             raise e
         finally:
             self.cursor = old_cursor
+            self.schema_name = old_schema_name
             cursor.close()
         return table_id, ml_table_id
 
-    def upsert_value(self, data_ml_json: dict, table_id: int = None, lang_code: LangCode = None,
+    def upsert_value(self, data_ml_json: dict, table_id: int = None, 
+                     data_json_compare: dict = None, lang_code: LangCode = None,
                      is_main: int = 0, data_json: dict = None, table_name: str = None,
                      ml_table_name: str = None, schema_name: str = None,
                      limit: int = DEFAULT_SQL_SELECT_LIMIT, order_by: str = None) -> tuple:
@@ -181,16 +188,21 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
         table_name = table_name or self.default_table_name
         ml_table_name = ml_table_name or self.default_ml_table_name
         id_column_name = GenericCRUD.generate_id_column_name(table_name)
+        ml_id_column_name = GenericCRUD.generate_id_column_name(ml_table_name)
 
         # check if the row exists in the ml_table
         name = data_ml_json.get("title") or data_ml_json.get("name")
+        name_compare = name
         if not name:
             raise ValueError("name or title is required for upsert_value")
-        table_id = table_id or self.get_id_by_name(table_name=table_name, ml_table_name=ml_table_name, name=name,
+        if data_json_compare:
+            name_compare = data_json_compare.get("title") or data_json_compare.get("name")
+
+        table_id = table_id or self.get_id_by_name(table_name=table_name, ml_table_name=ml_table_name, name=name_compare,
                                                    lang_code=lang_code,
                                                    id_column_name=id_column_name, order_by=order_by)
-        ml_table_id = self.get_ml_id_by_name(ml_table_name=ml_table_name, name=name, lang_code=lang_code,
-                                             id_column_name=id_column_name, order_by=order_by)
+        ml_table_id = self.get_ml_id_by_name(ml_table_name=ml_table_name, name=name_compare, lang_code=lang_code,
+                                             id_column_name=ml_id_column_name, order_by=order_by)
         if not table_id:
             return self.add_value(data_ml_json=data_ml_json, table_id=table_id, lang_code=lang_code, is_main=is_main,
                                   data_json=data_json, table_name=table_name, ml_table_name=ml_table_name)
@@ -201,12 +213,88 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
                                            ml_table_name=ml_table_name, schema_name=schema_name,
                                            limit=limit, order_by=order_by)
 
+    def upsert_value_with_abbreviations(self, data_ml_json: dict,  data_json_compare: dict = None,
+                                        table_id: int = None, lang_code: LangCode = None,
+                                        data_json: dict = None, table_name: str = None,
+                                        ml_table_name: str = None, schema_name: str = None,
+                                        limit: int = DEFAULT_SQL_SELECT_LIMIT, order_by: str = None) -> tuple:
+        self.schema_name = schema_name or self.schema_name
+        table_name = table_name or self.default_table_name
+        ml_table_name = ml_table_name or self.default_ml_table_name
+        id_column_name = GenericCRUD.generate_id_column_name(table_name)
+        ml_id_column_name = GenericCRUD.generate_id_column_name(ml_table_name)
+
+        # check if the row exists in the ml_table
+        name_and_abbreviations = data_ml_json.get("title") or data_ml_json.get("name")
+        if not name_and_abbreviations:
+            raise ValueError("name or title is required for upsert_value")
+        if data_json_compare:
+            name_and_abbreviations_compare = data_json_compare.get("title") or data_json_compare.get("name")
+        else:
+            name_and_abbreviations_compare = name_and_abbreviations
+
+        name = name_and_abbreviations.split(" (")[0]
+        name_compare = name_and_abbreviations_compare.split(" (")[0]
+        abbreviations = name_and_abbreviations.split(" (")[1][:-1]
+        abbreviations_list = abbreviations.split(", ")
+        data_ml_json_with_name = data_ml_json.copy()
+        data_ml_json_with_name["title"] = name
+        data_ml_json_with_abbreviation_list = []
+        for abbreviation in abbreviations_list:
+            data_ml_json_with_abbreviation = data_ml_json.copy()
+            data_ml_json_with_abbreviation["title"] = abbreviation
+            data_ml_json_with_abbreviation_list.append(data_ml_json_with_abbreviation)
+
+        table_id = table_id or self.get_id_by_name(table_name=table_name, ml_table_name=ml_table_name, name=name_compare,
+                                                   lang_code=lang_code,
+                                                   id_column_name=id_column_name, order_by=order_by)
+        ml_table_id = self.get_ml_id_by_name(ml_table_name=ml_table_name, name=name_compare, lang_code=lang_code,
+                                             id_column_name=ml_id_column_name, order_by=order_by)
+        ml_ids_list = []
+        if not table_id:
+            table_id, ml_table_id = self.add_value(data_ml_json=data_ml_json_with_name, table_id=table_id, lang_code=lang_code,
+                                                   is_main=1, data_json=data_json, table_name=table_name,
+                                                   ml_table_name=ml_table_name)
+            ml_ids_list.append(ml_table_id)
+            for data_ml_json_with_abbreviation in data_ml_json_with_abbreviation_list:
+                table_id, ml_table_id = self.add_value(data_ml_json=data_ml_json_with_abbreviation, table_id=table_id,
+                                                       lang_code=lang_code, is_main=0, data_json=data_json,
+                                                       table_name=table_name, ml_table_name=ml_table_name)
+                ml_ids_list.append(ml_table_id)
+        else:
+            ml_ids_list = self.get_ml_ids_by_id(table_id=table_id, ml_table_name=ml_table_name, lang_code=lang_code,
+                                                id_column_name=id_column_name, ml_id_column_name=ml_id_column_name,
+                                                order_by=order_by)
+            ml_ids_list.remove(ml_table_id)
+            table_id, main_ml_table_id = self.update_value_by_id(data_ml_json=data_ml_json_with_name, ml_table_id=ml_table_id,
+                                                                 table_id=table_id,
+                                                                 lang_code=lang_code, is_main=1, data_json=data_json,
+                                                                 table_name=table_name,
+                                                                 ml_table_name=ml_table_name, schema_name=schema_name,
+                                                                 limit=limit, order_by=order_by)
+            for index, data_ml_json_with_abbreviation in enumerate(data_ml_json_with_abbreviation_list):
+                if index < len(ml_ids_list):
+                    table_id, ml_table_id = self.update_value_by_id(data_ml_json=data_ml_json_with_abbreviation,
+                                                                    ml_table_id=ml_ids_list[index], table_id=table_id,
+                                                                    lang_code=lang_code, is_main=0, data_json=data_json,
+                                                                    table_name=table_name,
+                                                                    ml_table_name=ml_table_name, schema_name=schema_name,
+                                                                    limit=limit, order_by=order_by)
+                else:
+                    table_id, ml_table_id = self.add_value(data_ml_json=data_ml_json_with_abbreviation, table_id=table_id,
+                                                           lang_code=lang_code, is_main=0, data_json=data_json,
+                                                           table_name=table_name, ml_table_name=ml_table_name)
+                ml_ids_list.append(ml_table_id)
+            ml_ids_list.append(main_ml_table_id)
+        return table_id, ml_ids_list
+
     def get_values_tuple(self, table_id: int, lang_code: LangCode = None,
                          id_column_name: str = None, select_clause_value: str = "*",
                          order_by: str = None) -> tuple:
 
         lang_code_str = self._get_lang_code_str(lang_code=lang_code)
-        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(self.default_table_name)
+        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(
+            self.default_table_name)
         result = self.select_one_tuple_by_where(where=f"{id_column_name}=%s AND lang_code=%s",
                                                 params=(table_id, lang_code_str),
                                                 select_clause_value=select_clause_value,
@@ -219,17 +307,30 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
                         order_by: str = None) -> dict:
 
         lang_code_str = self._get_lang_code_str(lang_code=lang_code)
-        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(self.default_table_name)
+        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(
+            self.default_table_name)
         result = self.select_one_dict_by_where(where=f"{id_column_name}=%s AND lang_code=%s",
                                                params=(table_id, lang_code_str),
                                                order_by=order_by or f"{id_column_name} DESC")
 
         return result
 
+    def get_values_dict_list(self, table_id: int, lang_code: LangCode = None,
+                             id_column_name: str = None,
+                             order_by: str = None) -> list:
+        lang_code_str = self._get_lang_code_str(lang_code=lang_code)
+        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(
+            self.default_table_name)
+        result = self.select_multi_dict_by_where(where=f"{id_column_name}=%s AND lang_code=%s",
+                                                 params=(table_id, lang_code_str),
+                                                 order_by=order_by)
+        return result
+
     def get_main_values_tuple(self, table_id: int, id_column_name: str = None, select_clause_value: str = "*",
                               order_by: str = None) -> tuple:
 
-        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(self.default_table_name)
+        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(
+            self.default_table_name)
         result = self.select_one_tuple_by_where(where=f"{id_column_name}=%s AND is_main=1",
                                                 params=(table_id,),
                                                 select_clause_value=select_clause_value,
@@ -240,7 +341,8 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
     def get_main_values_dict(self, table_id: int, id_column_name: str = None, select_clause_value: str = "*",
                              order_by: str = None) -> dict:
 
-        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(self.default_table_name)
+        id_column_name = id_column_name or GenericCRUD.generate_id_column_name(
+            self.default_table_name)
         result = self.select_one_dict_by_where(where=f"{id_column_name}=%s AND is_main=1",
                                                params=(table_id,),
                                                select_clause_value=select_clause_value,
@@ -297,6 +399,16 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
         else:
             return None
 
+    def get_ml_ids_by_id(self, table_id: int, ml_table_name: str = None, lang_code: LangCode = None,
+                         id_column_name: str = None, ml_id_column_name: str = None, order_by: str = None) -> list:
+        lang_code_str = None if lang_code is None else lang_code.value
+        result = self.select_multi_tuple_by_where(view_table_name=self._get_view_name(ml_table_name),
+                                                  select_clause_value=ml_id_column_name,
+                                                  where=f"{id_column_name}=%s AND lang_code=%s",
+                                                  params=(table_id, lang_code_str),
+                                                  order_by=order_by)
+        return [row[0] for row in result]
+
     def delete_by_name(self, name: str,
                        lang_code: LangCode = None) -> None:
 
@@ -321,7 +433,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
     # Change the old row with is_main=1 to is_main=0
     def _update_old_main_value_to_zero(self, table_id: int, table_name: str) -> None:
 
-        data_ml_json = {"is_main": 0}
+        data_ml_json = {self.is_main_column_name: 0}
         id_column_name = GenericCRUD.generate_id_column_name(table_name)
         self.update_by_where(table_name=self.default_ml_table_name,
                              data_json=data_ml_json,
@@ -387,7 +499,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
             f"WHERE `{condition_column_name}` = \"{condition_column_value}\" " if (condition_column_name and
                                                                                    condition_column_value)
             else f"WHERE {condition_column_name} IS NULL ") + (
-                           f"ORDER BY {order_by} " if order_by else "") + f"LIMIT {limit}"
+            f"ORDER BY {order_by} " if order_by else "") + f"LIMIT {limit}"
         self.cursor.execute(select_query)
         result = self.cursor.fetchall()
         return result
