@@ -43,8 +43,8 @@ class GenericMapping(GenericCRUD, metaclass=MetaLogger, object=LOGGER_MAPPING_CO
         data_json = data_json or {}
         data_json[f"{entity_name1}_id"] = entity_id1
         data_json[f"{entity_name2}_id"] = entity_id2
-        return GenericCRUD.insert(self, schema_name=schema_name, data_json=data_json, table_name=table_name,
-                                  ignore_duplicate=ignore_duplicate)
+        return self.insert(schema_name=schema_name, data_json=data_json, table_name=table_name,
+                           ignore_duplicate=ignore_duplicate)
 
     # TODO: do we need delete_mapping_by_id?
     def delete_mapping_by_two_ids(self, *, entity_id1: int, entity_id2: int,
@@ -66,7 +66,7 @@ class GenericMapping(GenericCRUD, metaclass=MetaLogger, object=LOGGER_MAPPING_CO
 
         where = f"{entity_name1}_id=%s AND {entity_name2}_id=%s"
         params = (entity_id1, entity_id2)
-        GenericCRUD.delete_by_where(self, schema_name=schema_name, table_name=table_name, where=where, params=params)
+        self.delete_by_where(schema_name=schema_name, table_name=table_name, where=where, params=params)
 
     def select_multi_mapping_tuple_by_id(self, *, entity_id1: int, entity_id2: int,
                                          entity_name1: str = None, entity_name2: str = None,
@@ -89,9 +89,9 @@ class GenericMapping(GenericCRUD, metaclass=MetaLogger, object=LOGGER_MAPPING_CO
         table_name = f"{entity_name1}_{entity_name2}_view"
         where = f"{entity_name1}_id=%s AND {entity_name2}_id=%s"
         params = (entity_id1, entity_id2)
-        result = GenericCRUD.select_multi_tuple_by_where(self, schema_name=schema_name, view_table_name=table_name,
-                                                         select_clause_value=select_clause_value,
-                                                         where=where, params=params)
+        result = self.select_multi_tuple_by_where(schema_name=schema_name, view_table_name=table_name,
+                                                  select_clause_value=select_clause_value,
+                                                  where=where, params=params)
         return result
 
     def select_multi_mapping_dict_by_id(self, *, entity_id1: int, entity_id2: int,
@@ -112,4 +112,4 @@ class GenericMapping(GenericCRUD, metaclass=MetaLogger, object=LOGGER_MAPPING_CO
                                                        schema_name=schema_name,
                                                        select_clause_value=select_clause_value)
 
-        return [GenericCRUD.convert_to_dict(self, row, select_clause_value) for row in result]
+        return [self.convert_to_dict(row, select_clause_value) for row in result]
